@@ -10,9 +10,9 @@
    Tyrell DarkIce
 
    File     : AlsaDspSource.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/AlsaDspSource.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -56,7 +56,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: AlsaDspSource.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /* ===============================================  local function prototypes */
@@ -210,7 +210,7 @@ AlsaDspSource :: open ( void )                       throw ( Exception )
 
 
 /*------------------------------------------------------------------------------
- *  Check wether read() would return anything
+ *  Check whether read() would return anything
  *----------------------------------------------------------------------------*/
 bool
 AlsaDspSource :: canRead ( unsigned int    sec,
@@ -255,7 +255,7 @@ AlsaDspSource :: read (    void          * buf,
 
         // Check for buffer overrun
         if (ret == -EPIPE) {
-            reportEvent(1, "Buffer overrun!");
+            reportEvent(1, "AlsaDspSource :: Buffer overrun!");
             snd_pcm_prepare(captureHandle);
             ret = -EAGAIN;
         }
