@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : CastSink.h
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/CastSink.h $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -56,8 +56,8 @@
  *  This is an abstract class. A subclass should override at least
  *  the sendLogin() function.
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class CastSink : public Sink, public virtual Reporter
 {
@@ -431,7 +431,7 @@ class CastSink : public Sink, public virtual Reporter
         }
 
         /**
-         *  Get wether this stream is public.
+         *  Get whether this stream is public.
          *
          *  @return true if the stream is public, false otherwise.
          */
