@@ -5,9 +5,9 @@
    Tyrell ConfigSection
 
    File     : ConfigSection.h
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/ConfigSection.h $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -64,8 +64,8 @@
  *
  *  Knwon problem: you can't use '#' in any part of a key / value pair
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class ConfigSection : public virtual Referable
 {
