@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : Exception.h
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/Exception.h $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -59,8 +59,8 @@
  *  throw Exception( __FILE__, __LINE__, "describe the exception", code);
  *  </pre>
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class Exception
 {
