@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : FaacEncoder.h
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/FaacEncoder.h $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -70,8 +70,8 @@
 /**
  *  A class representing faac AAC encoder.
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class FaacEncoder : public AudioEncoder, public virtual Reporter
 {
@@ -399,7 +399,7 @@ class FaacEncoder : public AudioEncoder, public virtual Reporter
         }
 
         /**
-         *  Check wether encoding is in progress.
+         *  Check whether encoding is in progress.
          *
          *  @return true if encoding is in progress, false otherwise.
          */
