@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : IceCast2.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/IceCast2.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -67,7 +67,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: IceCast2.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /*------------------------------------------------------------------------------
@@ -233,7 +233,7 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
         sink->write( str, strlen( str));
     }
 
-    str = "\n\n";
+    str = "\r\n\r\n";
     sink->write( str, strlen( str));
     sink->flush();
 
