@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : IceCast2.h
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/IceCast2.h $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -53,8 +53,8 @@
  *  Class representing output to an IceCast2 server with
  *  ice login
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class IceCast2 : public CastSink
 {
