@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : MultiThreadedConnector.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/MultiThreadedConnector.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -53,7 +53,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: MultiThreadedConnector.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /* ===============================================  local function prototypes */
@@ -229,7 +229,7 @@ MultiThreadedConnector :: transfer ( unsigned long       bytes,
     dataBuffer   = new unsigned char[bufSize];
     dataSize     = 0;
 
-    reportEvent( 6, "MultiThreadedConnector :: tranfer, bytes", bytes);
+    reportEvent( 6, "MultiThreadedConnector :: transfer, bytes", bytes);
 
     for ( b = 0; !bytes || b < bytes; ) {
         if ( source->canRead( sec, usec) ) {
