@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : OpusLibEncoder.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/OpusLibEncoder.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
 
    Copyright notice:
 
@@ -36,11 +36,16 @@
 // compile only if configured for Ogg / Opus
 #ifdef HAVE_OPUS_LIB
 
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
 
 #include "Exception.h"
 #include "Util.h"
 #include "OpusLibEncoder.h"
 #include "CastSink.h"
+#include <cstring>
+#include <cstdlib>
 
 
 /* ===================================================  local data structures */
@@ -51,7 +56,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: OpusLibEncoder.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /* ===============================================  local function prototypes */
@@ -474,10 +479,10 @@ OpusLibEncoder :: flush ( void )
 
     int opusBufferSize = (1275*3+7)*getOutChannel();
     unsigned char * opusBuffer = new unsigned char[opusBufferSize];
-    short int * shortBuffer = new short int[480];
+    short int * shortBuffer = new short int[480*getInChannel()];
 
     // Send an empty audio packet along to flush out the stream.
-    memset( shortBuffer, 0, 480);
+    memset( shortBuffer, 0, 480*getInChannel()*sizeof(*shortBuffer));
     memset( opusBuffer, 0, opusBufferSize);
     int encBytes = opus_encode( opusEncoder, shortBuffer, 480, opusBuffer, opusBufferSize);
     if( encBytes == -1 ) {
