@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : OpusLibEncoder.h
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/OpusLibEncoder.h $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
 
    Copyright notice:
 
@@ -40,6 +40,8 @@
 #include "config.h"
 #endif
 
+#include <stdlib.h>
+
 #ifdef HAVE_OPUS_LIB
 #include <opus/opus.h>
 #include <ogg/ogg.h>
@@ -52,13 +54,15 @@
 #include "Exception.h"
 #include "Reporter.h"
 #include "AudioEncoder.h"
-#include "CastSink.h"
+#include "Sink.h"
 #ifdef HAVE_SRC_LIB
 #include <samplerate.h>
 #else
 #include "aflibConverter.h"
 #endif
 
+#include <stdio.h>
+#include <cstdlib>
 
 /* ================================================================ constants */
 
@@ -72,8 +76,8 @@
  *  A struct for containing the ogg opus header format, sent at the stream
  *  beginning.
  *
- *  @author $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author $Author$
+ *  @version $Revision$
  */
 struct OpusIdHeader {
     char magic[8];              /* "OpusHead" */
@@ -119,16 +123,16 @@ struct OpusIdHeader {
 /**
  *  A struct for containing the ogg opus comment header format
  *
- *  @author $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author $Author$
+ *  @version $Revision$
  */
 struct OpusCommentHeader {
     /**
      * Struct for each tag pair, in the form of a UTF-8
      * string, "TAG=value"
      *
-     * @author $Author: rafael@riseup.net $
-     * @version $Revision: 553 $
+     * @author $Author$
+     * @version $Revision$
      */
     struct Tags {
         unsigned int tag_len;   /* For each tag, how long the following tag is */
@@ -189,8 +193,8 @@ struct OpusCommentHeader {
  *  A class representing the ogg opus encoder linked as a shared object or
  *  as a static library.
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class OpusLibEncoder : public AudioEncoder, public virtual Reporter
 {
@@ -311,7 +315,7 @@ class OpusLibEncoder : public AudioEncoder, public virtual Reporter
          *  @exception Exception
          */
         inline
-        OpusLibEncoder (  CastSink      * sink,
+        OpusLibEncoder (  Sink      * sink,
                             unsigned int    inSampleRate,
                             unsigned int    inBitsPerSample,
                             unsigned int    inChannel,
@@ -356,7 +360,7 @@ class OpusLibEncoder : public AudioEncoder, public virtual Reporter
          *  @exception Exception
          */
         inline
-        OpusLibEncoder (  CastSink              * sink,
+        OpusLibEncoder (    Sink                  * sink,
                             const AudioSource     * as,
                             BitrateMode             outBitrateMode,
                             unsigned int            outBitrate,
@@ -443,7 +447,7 @@ class OpusLibEncoder : public AudioEncoder, public virtual Reporter
         }
 
         /**
-         *  Check wether encoding is in progress.
+         *  Check whether encoding is in progress.
          *
          *  @return true if encoding is in progress, false otherwise.
          */
