@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : OssDspSource.h
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/OssDspSource.h $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -51,8 +51,8 @@
 /**
  *  An audio input based on /dev/dsp-like raw devices
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class OssDspSource : public AudioSource, public virtual Reporter
 {
@@ -69,7 +69,7 @@ class OssDspSource : public AudioSource, public virtual Reporter
         int         fileDescriptor;
 
         /**
-         *  Indicates wether the low-level OSS DSP device is in a recording
+         *  Indicates whether the low-level OSS DSP device is in a recording
          *  state.
          */
         bool        running;
