@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : TcpSocket.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/TcpSocket.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -101,7 +101,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: TcpSocket.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /* ===============================================  local function prototypes */
@@ -256,7 +256,7 @@ TcpSocket :: open ( void )                       throw ( Exception )
 
 
 /*------------------------------------------------------------------------------
- *  Check wether read() would return anything
+ *  Check whether read() would return anything
  *----------------------------------------------------------------------------*/
 bool
 TcpSocket :: canRead (      unsigned int    sec,
@@ -318,9 +318,9 @@ TcpSocket :: read (     void          * buf,
                 break;
 
             default:
-		::close( sockfd);
-		sockfd = 0;
-		throw Exception( __FILE__, __LINE__, "recv error", errno);
+                ::close( sockfd);
+                sockfd = 0;
+                throw Exception( __FILE__, __LINE__, "recv error", errno);
         }
     }
 
@@ -329,7 +329,7 @@ TcpSocket :: read (     void          * buf,
 
 
 /*------------------------------------------------------------------------------
- *  Check wether read() would return anything
+ *  Check whether write() would send anything
  *----------------------------------------------------------------------------*/
 bool
 TcpSocket :: canWrite (    unsigned int    sec,
@@ -357,11 +357,11 @@ TcpSocket :: canWrite (    unsigned int    sec,
     ret = pselect( sockfd + 1, NULL, &fdset, NULL, &timespec, &sigset);
     
     if ( ret == -1 ) {
-	::close( sockfd);
-	sockfd = 0;
-        throw Exception( __FILE__, __LINE__, "select error");
+        ::close( sockfd);
+        sockfd = 0;
+        reportEvent(4,"TcpSocket :: canWrite, connection lost", errno);
     }
-
+  
     return ret > 0;
 }
 
@@ -389,8 +389,9 @@ TcpSocket :: write (    const void    * buf,
         if ( errno == EAGAIN ) {
             ret = 0;
         } else {
-	    ::close( sockfd);
-	    sockfd = 0;
+            ::close( sockfd);
+            sockfd = 0;
+            reportEvent(4,"TcpSocket :: write, send error", errno);
             throw Exception( __FILE__, __LINE__, "send error", errno);
         }
     }
