@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : TcpSocket.h
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/TcpSocket.h $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -52,8 +52,8 @@
 /**
  *  A TCP network socket
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class TcpSocket : public Source, public Sink, public virtual Reporter
 {
