@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : TwoLameLibEncoder.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/TwoLameLibEncoder.h $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -66,8 +66,8 @@
  *  A class representing the TwoLame encoder linked as a shared object or as
  *  a static library.
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class TwoLameLibEncoder : public AudioEncoder, public virtual Reporter
 {
@@ -249,7 +249,7 @@ class TwoLameLibEncoder : public AudioEncoder, public virtual Reporter
         }
 
         /**
-         *  Check wether encoding is in progress.
+         *  Check whether encoding is in progress.
          *
          *  @return true if encoding is in progress, false otherwise.
          */
