@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : VorbisLibEncoder.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/VorbisLibEncoder.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -40,7 +40,7 @@
 #include "Exception.h"
 #include "Util.h"
 #include "VorbisLibEncoder.h"
-
+#define VORBIS_MIN_BITRATE 45
 
 /* ===================================================  local data structures */
 
@@ -50,7 +50,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: VorbisLibEncoder.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /* ===============================================  local function prototypes */
@@ -79,6 +79,15 @@ VorbisLibEncoder :: init ( unsigned int     outMaxBitrate )
                          getInChannel() );
     }
 
+    if ( getOutBitrateMode() == abr || getOutBitrateMode() == cbr ) {
+        if ( getOutBitrate() < VORBIS_MIN_BITRATE ) {
+            throw Exception( __FILE__, __LINE__,
+                            "output bitrate is lower than libvorbis minimum",
+                            getOutBitrate() );
+        }
+        
+    }
+
     if ( getOutSampleRate() == getInSampleRate() ) {
         resampleRatio = 1;
         converter     = 0;
@@ -291,13 +300,13 @@ VorbisLibEncoder :: write ( const void    * buf,
             if ( bitsPerSample == 8 ) {
                 char          * buf8 = (char *) buf;
                 unsigned int    ix   = sampleSize * i;
-		unsigned int    iix  = ix;
+                unsigned int    iix  = ix;
                 buf8[i] = (buf8[ix] + buf8[++iix]) / 2;
             }
             if ( bitsPerSample == 16 ) {
                 short         * buf16 = (short *) buf;
                 unsigned int    ix    = (bitsPerSample >> 3) * i;
-		unsigned int    iix   = ix;
+                unsigned int    iix   = ix;
                 buf16[i] = (buf16[ix] + buf16[++iix]) / 2;
             }
         }
@@ -361,6 +370,7 @@ VorbisLibEncoder :: write ( const void    * buf,
     }
 
     delete[] shortBuffer;
+    
     vorbisBlocksOut();
 
     return processed;
@@ -402,7 +412,7 @@ VorbisLibEncoder :: vorbisBlocksOut ( void )                throw ( Exception )
             ogg_stream_packetin( &oggStreamState, &oggPacket);
 
             while ( ogg_stream_pageout( &oggStreamState, &oggPage) ) {
-                int    written;
+                int    written = 0;
                 
                 written  = getSink()->write(oggPage.header, oggPage.header_len);
                 written += getSink()->write( oggPage.body, oggPage.body_len);
