@@ -5,22 +5,22 @@
    Tyrell DarkIce
 
    File     : VorbisLibEncoder.h
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/VorbisLibEncoder.h $
-   
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
+
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License  
+    modify it under the terms of the GNU General Public License
     as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
-   
+
     This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of 
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-   
+
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
@@ -51,7 +51,7 @@
 #include "Exception.h"
 #include "Reporter.h"
 #include "AudioEncoder.h"
-#include "CastSink.h"
+#include "Sink.h"
 #ifdef HAVE_SRC_LIB
 #include <samplerate.h>
 #else
@@ -71,8 +71,8 @@
  *  A class representing the ogg vorbis encoder linked as a shared object or
  *  as a static library.
  *
- *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 553 $
+ *  @author  $Author$
+ *  @version $Revision$
  */
 class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
 {
@@ -199,7 +199,7 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
          *  @exception Exception
          */
         inline
-        VorbisLibEncoder (  CastSink      * sink,
+        VorbisLibEncoder (  Sink          * sink,
                             unsigned int    inSampleRate,
                             unsigned int    inBitsPerSample,
                             unsigned int    inChannel,
@@ -211,11 +211,11 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
                             unsigned int    outChannel    = 0,
                             unsigned int    outMaxBitrate = 0 )
                                                         throw ( Exception )
-            
+
                     : AudioEncoder ( sink,
                                      inSampleRate,
                                      inBitsPerSample,
-                                     inChannel, 
+                                     inChannel,
                                      inBigEndian,
                                      outBitrateMode,
                                      outBitrate,
@@ -244,7 +244,7 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
          *  @exception Exception
          */
         inline
-        VorbisLibEncoder (  CastSink              * sink,
+        VorbisLibEncoder (  Sink                  * sink,
                             const AudioSource     * as,
                             BitrateMode             outBitrateMode,
                             unsigned int            outBitrate,
@@ -253,7 +253,7 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
                             unsigned int            outChannel    = 0,
                             unsigned int            outMaxBitrate = 0 )
                                                             throw ( Exception )
-            
+
                     : AudioEncoder ( sink,
                                      as,
                                      outBitrateMode,
@@ -331,7 +331,7 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
         }
 
         /**
-         *  Check wether encoding is in progress.
+         *  Check whether encoding is in progress.
          *
          *  @return true if encoding is in progress, false otherwise.
          */
@@ -402,7 +402,11 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
                 return false;
             }
 
-            return getSink()->canWrite(sec, usec);
+            if ( 1 == vorbis_analysis_blockout( &vorbisDspState, &vorbisBlock) ) {
+              return getSink()->canWrite(sec, usec);
+            } else {
+              return true;
+            }
         }
 
         /**
@@ -447,4 +451,3 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
 
 
 #endif  /* VORBIS_LIB_ENCODER_H */
-
