@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : main.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/main.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Abstract : 
 
@@ -71,7 +71,7 @@ static Ref<DarkIce>     darkice;
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: main.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 /*------------------------------------------------------------------------------
  *  Default config file name
